This is unreleased documentation for the main (development) branch of crypto-glue.

CrlBuilder

Struct CrlBuilder 

pub struct CrlBuilder<P = Rfc5280>
where P: Profile,
{ /* private fields */ }
X.509 CRL builder

Implementations

Source

impl<P> CrlBuilder<P>
where P: Profile,

pub fn new(issuer: &Certificate, crl_number: CrlNumber) -> Result<Self>

Create a CrlBuilder with the given issuer and the given monotonic CrlNumber

pub fn new_with_this_update( issuer: &Certificate, crl_number: CrlNumber, this_update: Time, ) -> Result<Self>

Create a CrlBuilder with the given issuer, a given monotonic CrlNumber, and valid from the given this_update start validity date.

pub fn with_next_update(self, next_update: Option<Time>) -> Self

Make the CRL valid until the given next_update

pub fn with_certificates<I>(self, revoked: I) -> Self
where I: Iterator<Item = RevokedCert<P>>,

Add certificates to the revocation list