pub struct CrlBuilder<P = Rfc5280>where
P: Profile,{ /* private fields */ }Expand description
X.509 CRL builder
Implementations
Sourceimpl<P> CrlBuilder<P>where
P: Profile,
impl<P> CrlBuilder<P>where
P: Profile,
Sourcepub fn new(issuer: &Certificate, crl_number: CrlNumber) -> Result<Self>
pub fn new(issuer: &Certificate, crl_number: CrlNumber) -> Result<Self>
Create a CrlBuilder with the given issuer and the given monotonic CrlNumber
Sourcepub fn new_with_this_update(
issuer: &Certificate,
crl_number: CrlNumber,
this_update: Time,
) -> Result<Self>
pub fn new_with_this_update( issuer: &Certificate, crl_number: CrlNumber, this_update: Time, ) -> Result<Self>
Create a CrlBuilder with the given issuer, a given monotonic CrlNumber, and valid
from the given this_update start validity date.
Sourcepub fn with_next_update(self, next_update: Option<Time>) -> Self
pub fn with_next_update(self, next_update: Option<Time>) -> Self
Make the CRL valid until the given next_update
Sourcepub fn with_certificates<I>(self, revoked: I) -> Selfwhere
I: Iterator<Item = RevokedCert<P>>,
pub fn with_certificates<I>(self, revoked: I) -> Selfwhere
I: Iterator<Item = RevokedCert<P>>,
Add certificates to the revocation list